@@ -1,6 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
-#include "../src/yder.h"
+#include "../include/yder.h"
 
 void write_logs(const char * level) {
   y_log_message(Y_LOG_LEVEL_ERROR, "This is an error message while level is %s", level);
